pub struct SimilaritySessionCompletionQuery { /* private fields */ }Expand description
Chooses which similarity session completion data to read or update.
A query cannot select both a provider and a resolver. An empty query selects the whole session.
Implementations
Sourceimpl SimilaritySessionCompletionQuery
impl SimilaritySessionCompletionQuery
Sourcepub fn for_session() -> Self
pub fn for_session() -> Self
Selects the whole session.
Sourcepub fn for_node(node_id: SimilaritySessionNodeId) -> Self
pub fn for_node(node_id: SimilaritySessionNodeId) -> Self
Selects a node.
Sourcepub fn for_provider(provider_id: SimilarityProviderId) -> Self
pub fn for_provider(provider_id: SimilarityProviderId) -> Self
Selects a provider across the session.
Sourcepub fn for_resolver(resolver_id: SimilaritySessionResolverId) -> Self
pub fn for_resolver(resolver_id: SimilaritySessionResolverId) -> Self
Selects a resolver across the session.
Sourcepub fn with_provider(self, provider_id: SimilarityProviderId) -> Self
pub fn with_provider(self, provider_id: SimilarityProviderId) -> Self
Selects a provider within the current selection.
Sourcepub fn with_resolver(self, resolver_id: SimilaritySessionResolverId) -> Self
pub fn with_resolver(self, resolver_id: SimilaritySessionResolverId) -> Self
Selects a resolver within the current selection.
Sourcepub fn node_id(&self) -> Option<SimilaritySessionNodeId>
pub fn node_id(&self) -> Option<SimilaritySessionNodeId>
Returns the selected node, if any.
Sourcepub fn provider_id(&self) -> Option<SimilarityProviderId>
pub fn provider_id(&self) -> Option<SimilarityProviderId>
Returns the selected provider, if any.
Sourcepub fn resolver_id(&self) -> Option<SimilaritySessionResolverId>
pub fn resolver_id(&self) -> Option<SimilaritySessionResolverId>
Returns the selected resolver, if any.