pub type SimilarityEntityType = BNSimilarityEntityType;Expand description
The kind of object represented by a similarity entity.
Aliased Type
#[repr(u8)]pub enum SimilarityEntityType {
SimilarityEntityFunction = 0,
}pub type SimilarityEntityType = BNSimilarityEntityType;The kind of object represented by a similarity entity.
#[repr(u8)]pub enum SimilarityEntityType {
SimilarityEntityFunction = 0,
}